pub struct ApiTransaction {
pub index: String,
pub status: ApiTxStatus,
pub created_at: String,
pub updated_at: String,
pub fee_rate: Decimal,
pub incoming: ApiTransferDetails,
pub outgoing: ApiTransferDetails,
pub application_metadata: Option<ApiApplicationMetadata>,
}Expand description
Schema for saving and updating data in the database for each transaction
Fields
index: StringThe unique transaction index generated by the application for the current transaction
status: ApiTxStatusThe state of the transaction
created_at: StringThe date and time of the creation of the transaction
updated_at: StringThe date and time of update of the transaction
fee_rate: Decimalincoming: ApiTransferDetailsThe details of the transfer to ETO
outgoing: ApiTransferDetailsThe details of the transfer to receiver
application_metadata: Option<ApiApplicationMetadata>The application metadata of the tx