pub struct ApiTransferDetails {
pub transaction_id: Option<String>,
pub block_id: Option<String>,
pub username: String,
pub address: String,
pub network: ApiNetwork,
pub amount: Decimal,
pub exchange_rate: Decimal,
}Expand description
The details of the transfer information for traceability
Fields
transaction_id: Option<String>The unique id assigned by the network/exchange for this transfer
block_id: Option<String>The block id assigned by the network/exchange for this transfer
username: StringThe username of the sender / receiver
address: StringThe address of the sender / receiver
network: ApiNetworkThe network used to transfer amount between the sender and the receiver
amount: DecimalThe amount to be transferred between the sender and the receiver
exchange_rate: DecimalThe exchange rate from EUR to the decided currency.